@@ -1,10 +1,6 @@
 package Map::Tube::Node;
 
-$Map::Tube::Node::VERSION = '2.26';
-
-use 5.006;
-use Moo;
-use namespace::clean;
+$Map::Tube::Node::VERSION = '2.27';
 
 =head1 NAME
 
@@ -12,10 +8,14 @@ Map::Tube::Node - Class to represent the node in the map.
 
 =head1 VERSION
 
-Version 2.26
+Version 2.27
 
 =cut
 
+use 5.006;
+use Moo;
+use namespace::clean;
+
 use overload q{""} => 'as_string', fallback => 1;
 
 has id   => (is => 'ro');
@@ -26,7 +26,7 @@ has line => (is => 'ro');
 sub as_string {
     my ($self) = @_;
 
-    return $self->name;
+    return sprintf("%s (%s)", $self->name, $self->line);
 }
 
 =head1 AUTHOR
